measuretools.iterate_measures_backward_in_expr
==============================================

.. autofunction:: abjad.tools.measuretools.iterate_measures_backward_in_expr.iterate_measures_backward_in_expr
